#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-BcFKvuuHCGn5kbyi4CzSYK
key:                  dhall-1.42.3-BcFKvuuHCGn5kbyi4CzSYK
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  48f12e827017c05a42d4fed1c1881585
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-BcFKvuuHCGn5kbyi4CzSYK
depends:
    Diff-0.5-BjbdKLuZHF9G9mgcT2QyXB
    aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    aeson-pretty-0.8.10-4CX5mKtVMfDHxBh4AaJqv5
    ansi-terminal-1.1-BaaOJBYZHtd1MproObBlcZ
    atomic-write-0.2.1.1-7QFm4gk356NHCrveRtEOXa base-4.18.2.1
    base16-bytestring-1.0.2.0-DSxrKsTmVLa6G5QgZxymlm
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Gzh99I2Ds5LB1yZuFXcZ2A
    cborg-0.2.10.0-Af71fV89RLIFO0aPiPQi5t
    cborg-json-0.2.6.0-4dID2291e5r312Pb37uzCe containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-B5OLtApRTihJQyF2HUQHZN
    data-fix-0.3.4-G21XhnbgYkiGYYm86GrCq7 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-J7vCwVWtNG4J3dQuKeCS0b exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-CXCd0FAZola18wK277WuhH
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa haskeline-0.8.2.1
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-client-tls-0.3.6.4-BD4TqKfIzwr11ySZlgGnkK
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-HsgXVXUZbtJGVbAzhzLwYB
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-JJwr3105NpI16YFQY3IIVN
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-Av6doQWBFGD4lQ5rOW6gZP
    pretty-simple-4.1.4.0-HI4xv1bZRmyLER8GdHEa0T
    prettyprinter-1.7.1-7RKzVGBzgxT19LUdxVNO6E
    prettyprinter-ansi-terminal-1.1.4-3YWnN8nP22KOcxelH2Y20
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-5Vi2IPU7qCODLsKXYeBYLH
    serialise-0.2.6.1-LPlLNC0561bHMEUBNlqEe6 template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-6Pg7M6AFpHiAkWGWYjv3VE
    text-short-0.1.6.1-8NcYGOe22PmBFPHftzfoIZ
    th-lift-instances-0.1.20-58ImbwPHdD9FbI4STLnIYB time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-BZMXqomGfYu4rulQDFCFZv
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

